@@ -6,7 +6,7 @@ import jinja2
 
 from textflow.model.dataset import datasets
 from textflow.model.model import models
-from textflow.service.base import database as db
+from textflow.services.base import database as db
 
 logger = logging.getLogger(__name__)
 
@@ -17,7 +17,7 @@ class Project(db.Model):
     name = db.Column(db.String(80), nullable=False)
     description = db.Column(db.Text, default='No description provided.')
     type = db.Column(db.String(80), nullable=False)
-    documents = db.relationship('Document', backref='project', cascade='all, delete')
+    documents = db.relationship('Document', backref='project')
     labels = db.relationship('Label', backref='project', lazy=True, cascade='all, delete')
     users = db.relationship('Assignment', backref='project', lazy=True, cascade='all, delete')
     redundancy = db.Column(db.Integer, default=3)
