@@ -5,11 +5,11 @@ import logging
 import os
 
 import click
-from sqlalchemy.exc import SQLAlchemyError
+from sqlalchemy.exc import SQLAlchemyError, IntegrityError
 
-from textflow import TextFlow, service
+from textflow import TextFlow, services
 from textflow.model import *
-from textflow.service import db
+from textflow.services import db
 
 logger = logging.getLogger(__name__)
 
@@ -45,9 +45,9 @@ def cli(ctx, debug, mode, config_path, database_url):
         if 'SQLALCHEMY_TRACK_MODIFICATIONS' not in config:
             config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
         if 'SECRET_KEY' not in config:
-            config['SECRET_KEY'] = str(os.urandom(32))
+            config['SECRET_KEY'] = os.urandom(32).decode('latin1')
         if 'WTF_CSRF_SECRET_KEY' not in config:
-            config['WTF_CSRF_SECRET_KEY'] = str(os.urandom(32))
+            config['WTF_CSRF_SECRET_KEY'] = os.urandom(32).decode('latin1')
         ctx.obj['CONFIG'] = config
         with open(config_path, 'w') as fp:
             json.dump(config, fp)
@@ -143,7 +143,7 @@ def cli_project_update(ctx, project_id, header):
     with tf.app_context():
         db.create_all()
         try:
-            a = service.get_project.ignore_user(None, project_id)
+            a = services.get_project.ignore_user(None, project_id)
             with open(header, encoding='utf-8') as fp:
                 a.guideline_template = fp.read()
             db.session.commit()
@@ -161,12 +161,20 @@ def cli_project_delete(ctx, project_id):
     with tf.app_context():
         db.create_all()
         try:
-            p = service.get_project.ignore_user(None, project_id)
+            p = services.get_project.ignore_user(None, project_id)
             if p is not None:
-                db.session.delete(p)
-                db.session.commit()
+                if len(p.documents) > 0:
+                    logger.error('Error: Unable to delete project with ID={}. '
+                                 'This project is associated with one or more documents.'
+                                 .format(project_id))
+                else:
+                    db.session.delete(p)
+                    db.session.commit()
             else:
                 logger.error('Error: No such project with ID={}.'.format(project_id))
+        except IntegrityError as e:
+            db.session.rollback()
+            logger.error('Error: {}'.format(str(e)))
         except SQLAlchemyError as e:
             db.session.rollback()
             logger.error('Error: {}'.format(str(e)))
@@ -237,7 +245,7 @@ def cli_user_create(ctx):
     with tf.app_context():
         db.create_all()
         try:
-            users = service.list_users()
+            users = services.list_users()
             logger.info(users)
         except SQLAlchemyError as e:
             logger.error('Error: {}'.format(str(e)))
@@ -260,7 +268,7 @@ def cli_user_update(ctx, username, password):
     with tf.app_context():
         db.create_all()
         try:
-            users = service.filter_users(username=username)
+            users = services.filter_users(username=username)
             if len(users) == 1:
                 user = users[0]
                 user.set_password(password)
@@ -291,9 +299,9 @@ def cli_user_assign(ctx, username, project_id, role):
     with tf.app_context():
         db.create_all()
         try:
-            u = service.filter_users(username=username)
+            u = services.filter_users(username=username)
             if len(u) == 1:
-                r = service.get_assignment(user_id=u[0].id, project_id=project_id)
+                r = services.get_assignment(user_id=u[0].id, project_id=project_id)
                 if r is None:
                     if role is not None:
                         a = Assignment(user_id=u[0].id, project_id=project_id, role=role)
@@ -332,8 +340,8 @@ def cli_user_unassign(ctx, username, project_id):
     with tf.app_context():
         db.create_all()
         try:
-            u = service.filter_users(username=username)
-            status = service.remove_assignment(user_id=u[0].id, project_id=project_id)
+            u = services.filter_users(username=username)
+            status = services.remove_assignment(user_id=u[0].id, project_id=project_id)
             if status:
                 logger.info('Completed successfully.')
             else:
@@ -388,16 +396,36 @@ def cli_documents_upload(ctx, project_id, input):
     with tf.app_context():
         db.create_all()
         try:
-            for d in json.load(open(input)):
-                a = Document(id_str=d['id'], text=d['text'], meta=d['meta'], project_id=project_id)
-                db.session.add(a)
-            db.session.commit()
+            with open(input, 'r', encoding='utf-8') as fp:
+                for line in fp:
+                    d = json.loads(line)
+                    a = Document(id_str=d['id'], text=d['text'], meta=d['meta'], project_id=project_id)
+                    db.session.add(a)
+                db.session.commit()
             logger.info('Completed successfully.')
         except SQLAlchemyError as e:
             db.session.rollback()
             logger.error('Error: {}'.format(str(e)))
 
 
+@document_group.command(name='delete')
+@click.option('-p', '--project_id', prompt='Project id', help='Project ident')
+@click.pass_context
+def cli_documents_delete(ctx, project_id):
+    """Creates user using provided args
+
+    :param ctx: context
+    :param project_id: project id
+    :return: None
+    """
+    config = ctx.obj['CONFIG']
+    tf = TextFlow(config)
+    with tf.app_context():
+        db.create_all()
+        log = services.delete_documents.ignore_user(None, project_id)
+        logger.info('Completed successfully. Deleted {} documents.'.format(log))
+
+
 @annotation_group.command(name='create')
 @click.option('-p', '--project_id', prompt='Project ID', help='Project ident')
 @click.option('-u', '--user_id', prompt='User ID', help='User ident')
@@ -422,9 +450,9 @@ def cli_annotation_create(ctx, project_id, document_id, user_id, label, span):
     with tf.app_context():
         db.create_all()
         try:
-            doc = service.filter_document.ignore_user(None, project_id=int(project_id), id_str=document_id)
+            doc = services.filter_document.ignore_user(None, project_id=int(project_id), id_str=document_id)
             data = {'label': {'value': label}, 'span': {'start': span[0], 'length': span[1] - span[0]}}
-            service.add_annotation(project_id, user_id, doc.id, data)
+            services.add_annotation(project_id, user_id, doc.id, data)
             logger.info('Completed successfully.')
         except SQLAlchemyError as err:
             db.session.rollback()
